CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
36 lines
1.0 KiB
Common Lisp
36 lines
1.0 KiB
Common Lisp
|
|
#pragma OPENCL EXTENSION cl_khr_fp16 : enable
|
|
|
|
// FIXME: OpenCL's native_recip doesn't seem wired up to the ocml
|
|
// functions for f16/f64
|
|
|
|
half __ocml_native_rcp_f16(half);
|
|
|
|
// GCN: {{^}}test_native_recip_f16:
|
|
// GFX600: v_rcp_f32
|
|
// GFX700: v_rcp_f32
|
|
|
|
|
|
// GFX803: {{(flat|global|buffer)}}_load_{{(ushort|b16)}} [[VAL:v[0-9+]]],
|
|
// GFX803-NOT: [[VAL]]
|
|
// GFX803: v_rcp_f16{{(_e32)?}} [[RESULT:v[0-9]+]], [[VAL]]
|
|
// GFX803-NOT: [[RESULT]]
|
|
// GFX803: [[RESULT]]
|
|
// GFX803-NOT: [[RESULT]]
|
|
kernel void test_native_recip_f16(global half* restrict out, global half* restrict in) {
|
|
int id = get_local_id(0);
|
|
out[id] = __ocml_native_rcp_f16(in[id]);
|
|
}
|
|
|
|
// GCN: {{^}}test_native_recip_f32:
|
|
// GCN: {{(flat|global|buffer)}}_load_{{(dword|b32)}} [[VAL:v[0-9+]]],
|
|
// GCN-NOT: [[VAL]]
|
|
// GCN: v_rcp_f32{{(_e32)?}} [[RESULT:v[0-9]+]], [[VAL]]
|
|
// GCN-NOT: [[RESULT]]
|
|
// GCN: [[RESULT]]
|
|
// GCN-NOT: [[RESULT]]
|
|
kernel void test_native_recip_f32(global float* restrict out, global float* restrict in) {
|
|
int id = get_local_id(0);
|
|
out[id] = native_recip(in[id]);
|
|
}
|